Authors and contributors to django-email-log (listed alphabetically):

- Ivan Studinsky
- Alexey Kotenko
- Jannis
- Keryn Knight <kerynknight.com>
- Rodrigo Deodoro <http://deodoro.org>
- Serafeim Papastefanos <https://www.spapas.net>
- Trey Hunner <http://treyhunner.com>
